diff -ruN -x configure -x *~ -x ircd-hybrid-6.0.orig -x *.rej ircd-hybrid-6.0.orig/include/s_conf.h ircd-hybrid-6.0/include/s_conf.h
--- ircd-hybrid-6.0.orig/include/s_conf.h	Sat Jun 23 08:52:03 2001
+++ ircd-hybrid-6.0/include/s_conf.h	Sat Jun 23 07:55:42 2001
@@ -225,6 +225,7 @@
   time_t           hold;     /* Hold action until this time (calendar time) */
   struct Class*    c_class;     /* Class of connection */
   int              dns_pending; /* 1 if dns query pending, 0 otherwise */
+  int              map_done; /* used in m_map() to check for stray C:lines. hey, there aren't many of these created anyway, 16 bits isn't much */
   umode_t          allowed_umodes;
   umode_t          default_umodes;
 };
diff -ruN -x configure -x *~ -x ircd-hybrid-6.0.orig -x *.rej ircd-hybrid-6.0.orig/src/m_map.c ircd-hybrid-6.0/src/m_map.c
--- ircd-hybrid-6.0.orig/src/m_map.c	Sat Jun 23 08:52:02 2001
+++ ircd-hybrid-6.0/src/m_map.c	Sat Jun 23 08:48:09 2001
@@ -25,6 +25,7 @@
 #include "irc_string.h"
 #include "send.h"
 #include "s_log.h"
+#include "s_conf.h"
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -45,10 +46,25 @@
 static void map_send_server(struct Client* sptr, char* sender_prefix, struct Client* current)
 {
   struct Client* acptr;
+  struct ConfItem* aconf;
 
   if (!current->serv)
     return; /* this should never happen, but let's be safe... */
 
+  if (!(aconf = current->serv->nline))
+    {
+      if (current != &me)
+	sendto_ops_flag(UMODE_DEBUG, "WTF: No N:line attached to server %s in m_map()", current->name);
+    }
+  else 
+    {
+      if (aconf->map_done)
+	{
+	  sendto_ops_flag(UMODE_DEBUG, "WTF: already done %s (%d) in m_map()", current->name, aconf->map_done);
+	}
+      aconf->map_done = 1;
+    }
+
   /* header should be formatted for us already */
   sendto_one(sptr, form_str(RPL_MAP), me.name, sender_prefix, header, current->name);
 
@@ -110,6 +126,20 @@
       header_length = 0;
       header[0] = '\0';
       map_send_server(sptr, parv[0], &me);
+      {
+	struct ConfItem* conf;
+	for (conf = ConfigItemList; conf; conf = conf->next)
+	  {
+	    if (conf->status != CONF_NOCONNECT_SERVER)
+	      continue;
+	    if (conf->map_done)
+	      {
+		conf->map_done = 0; /* clear it for the next map */
+		continue;
+	      }
+	    sendto_one(sptr, form_str(RPL_MAP), me.name, parv[0], "** ", conf->name);
+	  }
+      }
       sendto_one(sptr,form_str(RPL_ENDOFMAP),me.name,parv[0]);
     }
   else
diff -ruN -x configure -x *~ -x ircd-hybrid-6.0.orig -x *.rej ircd-hybrid-6.0.orig/src/s_conf.c ircd-hybrid-6.0/src/s_conf.c
--- ircd-hybrid-6.0.orig/src/s_conf.c	Sat Jun 23 08:52:03 2001
+++ ircd-hybrid-6.0/src/s_conf.c	Sat Jun 23 08:05:22 2001
@@ -189,6 +189,7 @@
   memset(aconf, 0, sizeof(struct ConfItem));
   aconf->status       = CONF_ILLEGAL;
   aconf->ipnum.s_addr = INADDR_NONE;
+  aconf->map_done = 0;
 
 #if defined(NULL_POINTER_NOT_ZERO)
   aconf->next = NULL;
